@@ -84,15 +84,7 @@ if __name__ == "__main__":
     print_line("Jinja", time_jinja)
     print_line("FastApi", time_fastapi)
     print_separator()
-    benchmark_no_cache(render_jinjax_simple)
-    print_separator()
-    benchmark_auto_reload(render_jinjax_simple)
-    print_separator()
-    benchmark_no_auto_reload(render_jinjax_simple)
-    print_separator()
-    benchmark_no_cache(render_jinjax_real)
-    print_separator()
     benchmark_auto_reload(render_jinjax_real)
-    print_separator()
+    print()
     benchmark_no_auto_reload(render_jinjax_real)
     print()
